Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/monadc/__init__.py | (no class) | 10 | 0 | 0 | 100%
src/monadc/decorators.py | (no class) | 33 | 0 | 3 | 100%
src/monadc/either/__init__.py | (no class) | 4 | 0 | 0 | 100%
src/monadc/either/either.py | Either | 40 | 25 | 0 | 38%
src/monadc/either/either.py | (no class) | 36 | 0 | 0 | 100%
src/monadc/either/left.py | Left | 50 | 0 | 0 | 100%
src/monadc/either/left.py | (no class) | 38 | 0 | 0 | 100%
src/monadc/either/right.py | Right | 46 | 0 | 0 | 100%
src/monadc/either/right.py | (no class) | 38 | 0 | 0 | 100%
src/monadc/option/__init__.py | (no class) | 4 | 0 | 0 | 100%
src/monadc/option/nil.py | NilType | 64 | 3 | 0 | 95%
src/monadc/option/nil.py | (no class) | 55 | 0 | 0 | 100%
src/monadc/option/option.py | Option | 55 | 44 | 0 | 20%
src/monadc/option/option.py | (no class) | 55 | 0 | 0 | 100%
src/monadc/option/some.py | Some | 79 | 5 | 0 | 94%
src/monadc/option/some.py | (no class) | 54 | 0 | 0 | 100%
src/monadc/result/__init__.py | (no class) | 4 | 0 | 0 | 100%
src/monadc/result/err.py | Err | 43 | 0 | 0 | 100%
src/monadc/result/err.py | (no class) | 32 | 0 | 0 | 100%
src/monadc/result/ok.py | Ok | 47 | 0 | 0 | 100%
src/monadc/result/ok.py | (no class) | 32 | 0 | 0 | 100%
src/monadc/result/result.py | Result | 33 | 23 | 0 | 30%
src/monadc/result/result.py | (no class) | 29 | 0 | 0 | 100%
src/monadc/try_/__init__.py | (no class) | 4 | 0 | 0 | 100%
src/monadc/try_/failure.py | Failure | 51 | 2 | 0 | 96%
src/monadc/try_/failure.py | (no class) | 28 | 0 | 0 | 100%
src/monadc/try_/success.py | Success | 53 | 0 | 0 | 100%
src/monadc/try_/success.py | (no class) | 27 | 0 | 0 | 100%
src/monadc/try_/try_.py | Try | 29 | 15 | 0 | 48%
src/monadc/try_/try_.py | (no class) | 26 | 0 | 0 | 100%
src/monadc/utils.py | (no class) | 23 | 0 | 0 | 100%
Total |  | 1122 | 117 | 3 | 90%

No items found using the specified filter.